@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/installer/RCS/windows.tcl,v $
-# $Date: 2000/02/02 10:09:16 $
-# $Revision: 1.18.1.19 $
+# $Date: 2001/06/13 07:20:29 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -45,7 +45,7 @@ proc install {argv} {
 #
 # Info
 #
-    if !{$NoGUI} {
+    if {!$NoGUI} {
 	grid [frame $w.sep2 -bg red] - -sticky ew -pady 2
 	grid [label $w.info] -columnspan 2 -sticky ew
     }
