@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Info.tcl,v $
-# $Date: 2000/02/04 14:49:36 $
-# $Revision: 1.18.1.43 $
+# $Date: 2001/07/10 15:36:11 $
+# $Revision: 1.18.1.46 $
 #
 package provide zircon 1.18
 #
@@ -60,7 +60,7 @@ proc Info {args} {
     set idata(text) [set oft $w.info]
     scrollbar $w.vscroller -command "$oft yview"
     text $oft -height 10 -width 80 \
-      -yscrollcommand "setScroll $name $oft $w.vscroller" -borderwidth 2
+      -yscrollcommand "$w.vscroller set" -borderwidth 2
     rebind $oft $idata(net)
     bind $oft <Configure> {%W see end ; notIdle %W}
     bind $w <Visibility> {notIdle %W}
@@ -78,19 +78,19 @@ proc Info {args} {
 #
 proc info_delete {this} { mcnDelete $this ITO[$this net] info }
 #
-proc info_onShow {this} { }
+proc info_onShow {unusedthis} { }
 #
 proc info_clear {this args} {
    [$this text] delete 1.0 end
    update idletasks
 }
 #
-proc info_send {this string args} {
+proc info_send {this str args} {
     if {[[$this net] raw]} {
 	$this configure -hpos 0
-	$this addText {} ":>$string"
-	$this addHist $string
-	[$this net] sendRaw $string
+	$this addText {} ":>$str"
+	$this addHist $str
+	[$this net] sendRaw $str
     } { bell }
 }
 #
@@ -108,7 +108,7 @@ proc info_call {this op pars} {
 	    } {
 		grid forget $idata(window).icmd
 	    }
-	    return
+	    return {}
 	}
     users { return [$idata(net) users] }
     }
@@ -128,17 +128,17 @@ proc info_popup {this} {
     return $this
 }
 #
-proc info_insert {this text} {
-    switch {} $text return
+proc info_insert {this txt} {
+    if {$txt == {}} return
     set ent [$this window].icmd.entry
-    while {[regexp "(\[^\n\]*)\n(.*)" $text d line text]} {
+    while {[regexp "(\[^\n\]*)\n(.*)" $txt d line text]} {
 	switch {} $line continue
 	tkEntryInsert $ent $line
 	$this doCmd $ent
 	$ent delete 0 end
     }
-    switch {} $text {} default {
-	$ent insert insert $text
+    if {$txt != {}} {
+	$ent insert insert $txt
 	tkEntrySeeInsert $ent
     }
 }
