@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Object.tcl,v $
-# $Date: 2000/02/02 10:09:12 $
-# $Revision: 1.18.1.16 $
+# $Date: 2001/07/12 15:35:50 $
+# $Revision: 1.18.1.20 $
 #
 # ----------------------------------------------------------------------
 #   AUTHOR:  Lindsay Marshall <lindsay.marshall@newcastle.ac.uk>
@@ -24,13 +24,20 @@ proc newName {thing} {
 }
 #
 proc class {name vars args} {
+    # FRINK: nocheck
     global $name Private.$name Configure.$name
+    # FRINK: nocheck
     set $name {}
     foreach {x y z} $vars {
+	# FRINK: nocheck
 	lappend $name $x $y
+	# FRINK: nocheck
 	set Configure.${name}($x) $z
     }
-    switch {} $args {} default {set Private.$name [lindex $args 0]}
+    if {$args != {}} {
+	# FRINK: nocheck
+        set Private.$name [lindex $args 0]
+    }
 }
 #
 proc initObj {name args} {
@@ -46,10 +53,10 @@ proc makeObj {types pars} {
     eval initObj $this $types
     uplevel #0 set ${this}(name) $this
     set mt [string tolower $mt]
-    switch {} [info proc ${mt}_call] {
-	proc $this {op args} "objCall $mt $this \$op \$args"
+    switch {} [info procs ${mt}_call] {
+	proc $this {unusedop args} "objCall $mt $this \$unusedop \$args"
     } default {
-        proc $this {op args}  "${mt}_call $this \$op \$args"
+        proc $this {unusedop args}  "${mt}_call $this \$unusedop \$args"
     }
     eval $this configure $pars
     return $this
@@ -65,10 +72,10 @@ proc makeNObj {name net types pars} {
     }
     set mt [string tolower $mt]
     $net register ${mt}s $this
-    switch {} [info proc ${mt}_call] {
-	proc $this {op args} "objCall $mt $this \$op \$args"
+    switch {} [info procs ${mt}_call] {
+	proc $this {unusedop args} "objCall $mt $this \$unusedop \$args"
     } default {
-        proc $this {op args}  "${mt}_call $this \$op \$args"
+        proc $this {unusedop args}  "${mt}_call $this \$unusedop \$args"
     }
     eval $this configure $pars
     return $this
@@ -91,7 +98,7 @@ proc clone {obj} {
     set nn [newName $OType($obj)]
     upvar #0 $nn cdata
     array set cdata [array get data]
-    proc $nn {op args} "objCall [string tolower $OType($obj)] $nn \$op \$args"
+    proc $nn {unusedop args} "objCall [string tolower $OType($obj)] $nn \$unusedop \$args"
     set OType($nn) $OType($obj)
     set Clone($nn) $obj
     return $nn
@@ -103,10 +110,13 @@ proc unclone {this} {
     if {![info exists Clone($this)]} { return 0 }
     set mt $Clone($this)
     set typ $OType($this)
+    # FRINK: nocheck
     global Configure.$typ
+    # FRINK: nocheck
     foreach x [array names Configure.$typ] {
         if {[$mt $x] != $cdata($x)} { $mt configure -$x $cdata($x) }
     }
+    # FRINK: nocheck
     unset cdata $OType($this) Clone($this)
     rename $this {}
     return 1
