@@ -7,9 +7,9 @@
 array set Ops {
     server	{Links Version Motd Time Trace Admin Lusers Info Stats Oper}
     ircSrv	{Connect Rehash Restart Squit}
-    user	{Who Whois Whowas Mode CTCP DCC Invite Message Notice \
+    user	{Who Whois Whowas Mode CTCP DCC Invite Memo Message Notice \
 	         Finger Time Trace Userhost}
     ircop	{Kill}
-    userMenu {Whois Message Notice Time CTCP DCC Notify Ignore Silence Finger}
+    userMenu {Whois Message Notice Action Time CTCP DCC Notify Ignore Silence Finger}
     chanop	{Speak ChanOp Kick Ban BanKick}
 }
