@@ -1,7 +1,7 @@
 #
 # $Source: /home/nlfm/Working/Zircon/Released/plugins/Dcc/RCS/dccsend.tcl,v $
-# $Date: 1998/05/19 16:13:14 $
-# $Revision: 1.18.1.6 $
+# $Date: 2001/07/10 15:36:14 $
+# $Revision: 1.18.1.8 $
 #
 package provide Dcc 1.18
 #
@@ -14,17 +14,16 @@ proc acceptSend {net key file usr chan hst port} {
     if {[catch {set x [lsearch $Offer($usr) "$key *"]}]} {
 	catch {close $chan}
 	tellError {} {Cancelled send accepted.}
-	return
+	return 0
     }
     set v [lindex $Offer($usr) $x]
     close [lindex $v 2]
     if {[catch {set fd [open "|[file join $zircon(lib) plugins Dcc dccsend] $file\
       [lindex $v 4] $usr <@$chan 2>@$chan" r]} msg]} {
 	close $chan
-	tellError {} {Prog error} "Cannot run DCC helper program \
-dccsend - \"$msg\"
+	tellError {} {Prog error} "Cannot run DCC helper program dccsend - \"$msg\"
 Check your installation"
-	return
+	return 0
     }
     catch {fconfigure $fd -buffering line -translation lf}
     fileevent $fd readable "handleInfo $net $fd"
@@ -36,6 +35,7 @@ Check your installation"
     switch {} $Offer($usr) {unset Offer($usr)}
     if {[winfo exists .@dls$net]} { buildDCCList $net }
     dccWindow $fd $usr Send $file
+    return 1
 }
 } default {
 proc acceptSend {net key file usr chan hst port} {
@@ -44,7 +44,7 @@ proc acceptSend {net key file usr chan hst port} {
     if {[catch {set x [lsearch $Offer($usr) "$key *"]}]} {
 	catch {close $chan}
 	tellError {} {Cancelled send accepted.}
-	return
+	return 0
     }
     set v [lindex $Offer($usr) $x]
     close [lindex $v 2]
@@ -53,7 +53,7 @@ proc acceptSend {net key file usr chan hst port} {
     lappend Send($usr) $v
     listdel Offer($usr) $x
     switch {} $Offer($usr) {unset Offer($usr)}
-    if {[ catch {open $file RDONLY} g]} {
+    if {[catch {open $file RDONLY} g]} {
         endDCC Send $usr $chan $net "Cannot read $file : $g"
         return 0
     }
@@ -90,6 +90,7 @@ proc acceptSend {net key file usr chan hst port} {
     fileevent $chan readable "dccSendEvent $chan $g $st $leng $usr $net"
     dccWindow $chan $usr Send $file
     if {[winfo exists .@dls$net]} { buildDCCList $net }
+    return 1
 }
 #
 proc dccSendEvent {sk fd st leng who net} {
@@ -112,13 +113,13 @@ proc dccSendEvent {sk fd st leng who net} {
     set cl 0
     binary scan $l I1 cl
     if {$cl != $tl($sk)} { return }
-    if [eof $fd] {
+    if {[eof $fd]} {
         if {[set st [expr {[clock seconds] - $st}]] == 0} {
 	    set st 1
         }
 	close $fd
 	endDCC Send $who $sk $net \
-	  "Transfer completed. [expr $leng / (1000.0 * $st)] Kbytes/sec"
+	  "Transfer completed. [expr {$leng / (1000.0 * $st)}] Kbytes/sec"
 	return
     }
     if {[catch {set buffer [read $fd [$net dccblock]]} msg]} {
@@ -132,7 +133,7 @@ proc dccSendEvent {sk fd st leng who net} {
         }
 	close $fd
 	endDCC Send $who $sk $net \
-	  "Transfer completed. [expr $leng / (1000.0 * $st)] Kbytes/sec"
+	  "Transfer completed. [expr {$leng / (1000.0 * $st)}] Kbytes/sec"
 	return
     }
     incr tl($sk) $lng
